@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright :( C) 2003 - 2012 by Claude Bulin
+ *  copyright :( C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -224,6 +224,7 @@ typedef enum {
 	FILE_IS_NONE = 0,
 	FILE_IS_FLAC,
 	FILE_IS_WAV,
+	// FILE_IS_BFW,	// BROADCAST WAVE FORMAT
 	FILE_IS_MP3,
 	FILE_IS_OGG,
 	/* Les fichiers au format AAC, portant l'extension
@@ -624,6 +625,7 @@ void		FileScanDB_action( gboolean BoolAllScan );
 // 
 #include "fileselect.h"
 
+void		fileanalyze_remove_entetefile_detail( void );
 void		fileanalyze_remove_entetefile( void );
 void		fileanalyze_add_file_to_treeview( TYPE_FILESELECTION p_TypeFileselection, GSList *p_list );
 gboolean	fileanalyze_exist( DETAIL *detail, gchar *NewExt );
