@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -564,7 +564,8 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 		g_print ("\tGETTEXT_PACKAGE    = %s\n", GETTEXT_PACKAGE);
 		g_print ("\tLOCALE_DIR         = %s\n", LOCALE_DIR);	
 	}
-	setlocale (LC_ALL, "");
+		
+	setlocale( LC_ALL, "" );
 	bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
@@ -574,13 +575,13 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	
 	GetInfo_cpu_print ();
 	
-	/* IF Segmentation fault */
+	// IF Segmentation fault 
 	signal (SIGSEGV, segfault_handler);
 	
 	config_read();
 	
-	gtk_set_locale ();
-	gtk_init (&argc, &argv);
+	setlocale( LC_ALL, "" );
+	gtk_init( &argc, &argv );
 
 	/*
 	Code revu depuis:
@@ -683,7 +684,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	PathShareProjet = NULL;
 	Path = NULL;
 
-	gtk_builder_set_translation_domain  (GtkXcfaProjet, gtk_set_locale ());
+	gtk_builder_set_translation_domain  (GtkXcfaProjet, setlocale( LC_ALL, "" ) );
 	gtk_builder_connect_signals (GtkXcfaProjet, NULL);
 	WindMain = GTK_WIDGET (GLADE_GET_OBJECT("wind_main"));
 	
